from termcolor import colored

art = """
                            nn
                            no i
                            o
                          mpo    l
                      opppn       opn
                    ooppopo         oppol
                  oopoppoo           opopo
                oopooono             oppppo
                pppppomp               oppppo
              opppo  p                 mppppl
              oppon om      onm         ooppo
              loppp no     no  on         opoo
              npppono     o      no       pppo
              oppo k   om         o  n  mpppo
              opppo     ol       nn nm  ooppo
              lppppo     oo    no  mo  ooppo
                oppppn      onno   ln  oopoo
                ooppppm      n   no opppoo
                  opopppo       mpoppopoo
                    nppppo      pppppo
                        oooo    opooo

  .ooooo oo oooo  oooo   .oooo.    .oooo.o  .oooo.   oooo d8b
  d88' `888  `888  `888  `P  )88b  d88(  "8 `P  )88b  `888""8P
  888   888   888   888   .oP"888  `"Y88b.   .oP"888   888
  888   888   888   888  d8(  888  o.  )88b d8(  888   888
  `V8bod888   `V88V"V8P' `Y888""8o 8""888P' `Y888""8o d888b
        888.
        8P'
        "
"""
ASCII_ART = colored(art, "blue", attrs=["bold", "blink", "dark"])
